##  Restarting a Survey
Restarting a survey makes a finished survey available again for respondents to edit or add their responses. This option is useful if the survey is finished before receiving responses from all participants.
**Tip**
  * Restarting a survey doesn’t create a new survey run and doesn’t send out any new notifications.
  * If you adjust the scope, design, recipients, or other settings of a finished survey it becomes a new survey and triggers new email notifications. In this way you can reuse, modify, or extend a previously used survey questionnaire. To learn more, see [Creating a Fresh Survey Run from a Finished Survey](https://help.sap.com/docs/leanix/ea/creating-survey?locale=en-US&state=PRODUCTION&version=CLOUD#loio27598eba7a441014ac0faa69a0249eaa__creating_a_fresh_survey_run_from_a_finished_survey).


To restart a survey, follow these steps:
  1. Select the finished survey from the Manage Surveys section.
  2. From the three-dot menu at the top, click Restart.


![Restarting a Survey](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27514a147a441014a0d1bddda9849ca6_LowRes.png)
Restarting a Survey
